﻿/*
 * FCKeditor - The text editor for Internet - http://www.fckeditor.net
 * Copyright (C) 2003-2010 Frederico Caldeira Knabben
 *
 * == BEGIN LICENSE ==
 *
 * Licensed under the terms of any of the following licenses at your
 * choice:
 *
 *  - GNU General Public License Version 2 or later (the "GPL")
 *    http://www.gnu.org/licenses/gpl.html
 *
 *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
 *    http://www.gnu.org/licenses/lgpl.html
 *
 *  - Mozilla Public License Version 1.1 or later (the "MPL")
 *    http://www.mozilla.org/MPL/MPL-1.1.html
 *
 * == END LICENSE ==
 *
 * Khmer language file.
 */

var FCKLang =
{
// Language direction : "ltr" (left to right) or "rtl" (right to left).
Dir					: "ltr",

ToolbarCollapse		: "បង្រួមរបាឧបរកណ៍",
ToolbarExpand		: "ពង្រីករបាឧបរណ៍",

// Toolbar Items and Context Menu
Save				: "រក្សាទុក",
NewPage				: "ទំព័រថ្មី",
Preview				: "មើលសាកល្បង",
Cut					: "កាត់យក",
Copy				: "ចំលងយក",
Paste				: "ចំលងដាក់",
PasteText			: "ចំលងដាក់ជាអត្ថបទធម្មតា",
PasteWord			: "ចំលងដាក់ពី Word",
Print				: "បោះពុម្ភ",
SelectAll			: "ជ្រើសរើសទាំងអស់",
RemoveFormat		: "លប់ចោល ការរចនា",
InsertLinkLbl		: "ឈ្នាប់",
InsertLink			: "បន្ថែម/កែប្រែ ឈ្នាប់",
RemoveLink			: "លប់ឈ្នាប់",
VisitLink			: "Open Link",	//MISSING
Anchor				: "បន្ថែម/កែប្រែ យុថ្កា",
AnchorDelete		: "Remove Anchor",	//MISSING
InsertImageLbl		: "រូបភាព",
InsertImage			: "បន្ថែម/កែប្រែ រូបភាព",
InsertFlashLbl		: "Flash",
InsertFlash			: "បន្ថែម/កែប្រែ Flash",
InsertTableLbl		: "តារាង",
InsertTable			: "បន្ថែម/កែប្រែ តារាង",
InsertLineLbl		: "បន្ទាត់",
InsertLine			: "បន្ថែមបន្ទាត់ផ្តេក",
InsertSpecialCharLbl: "អក្សរពិសេស",
InsertSpecialChar	: "បន្ថែមអក្សរពិសេស",
InsertSmileyLbl		: "រូបភាព",
InsertSmiley		: "បន្ថែម រូបភាព",
About				: "អំពី FCKeditor",
Bold				: "អក្សរដិតធំ",
Italic				: "អក្សរផ្តេក",
Underline			: "ដិតបន្ទាត់ពីក្រោមអក្សរ",
StrikeThrough		: "ដិតបន្ទាត់ពាក់កណ្តាលអក្សរ",
Subscript			: "អក្សរតូចក្រោម",
Superscript			: "អក្សរតូចលើ",
LeftJustify			: "តំរឹមឆ្វេង",
CenterJustify		: "តំរឹមកណ្តាល",
RightJustify		: "តំរឹមស្តាំ",
BlockJustify		: "តំរឹមសងខាង",
DecreaseIndent		: "បន្ថយការចូលបន្ទាត់",
IncreaseIndent		: "បន្ថែមការចូលបន្ទាត់",
Blockquote			: "Blockquote",	//MISSING
CreateDiv			: "Create Div Container",	//MISSING
EditDiv				: "Edit Div Container",	//MISSING
DeleteDiv			: "Remove Div Container",	//MISSING
Undo				: "សារឡើងវិញ",
Redo				: "ធ្វើឡើងវិញ",
NumberedListLbl		: "បញ្ជីជាអក្សរ",
NumberedList		: "បន្ថែម/លប់ បញ្ជីជាអក្សរ",
BulletedListLbl		: "បញ្ជីជារង្វង់មូល",
BulletedList		: "បន្ថែម/លប់ បញ្ជីជារង្វង់មូល",
ShowTableBorders	: "បង្ហាញស៊ុមតារាង",
ShowDetails			: "បង្ហាញពិស្តារ",
Style				: "ម៉ូត",
FontFormat			: "រចនា",
Font				: "ហ្វុង",
FontSize			: "ទំហំ",
TextColor			: "ពណ៌អក្សរ",
BGColor				: "ពណ៌ផ្ទៃខាងក្រោយ",
Source				: "កូត",
Find				: "ស្វែងរក",
Replace				: "ជំនួស",
SpellCheck			: "ពិនិត្យអក្ខរាវិរុទ្ធ",
UniversalKeyboard	: "ក្តារពុម្ភអក្សរសកល",
PageBreakLbl		: "ការផ្តាច់ទំព័រ",
PageBreak			: "បន្ថែម ការផ្តាច់ទំព័រ",

Form			: "បែបបទ",
Checkbox		: "ប្រអប់ជ្រើសរើស",
RadioButton		: "ប៉ូតុនរង្វង់មូល",
TextField		: "ជួរសរសេរអត្ថបទ",
Textarea		: "តំបន់សរសេរអត្ថបទ",
HiddenField		: "ជួរលាក់",
Button			: "ប៉ូតុន",
SelectionField	: "ជួរជ្រើសរើស",
ImageButton		: "ប៉ូតុនរូបភាព",

FitWindow		: "Maximize the editor size",	//MISSING
ShowBlocks		: "Show Blocks",	//MISSING

// Context Menu
EditLink			: "កែប្រែឈ្នាប់",
CellCM				: "Cell",	//MISSING
RowCM				: "Row",	//MISSING
ColumnCM			: "Column",	//MISSING
InsertRowAfter		: "Insert Row After",	//MISSING
InsertRowBefore		: "Insert Row Before",	//MISSING
DeleteRows			: "លប់ជួរផ្តេក",
InsertColumnAfter	: "Insert Column After",	//MISSING
InsertColumnBefore	: "Insert Column Before",	//MISSING
DeleteColumns		: "លប់ជួរឈរ",
InsertCellAfter		: "Insert Cell After",	//MISSING
InsertCellBefore	: "Insert Cell Before",	//MISSING
DeleteCells			: "លប់សែល",
MergeCells			: "បញ្ជូលសែល",
MergeRight			: "Merge Right",	//MISSING
MergeDown			: "Merge Down",	//MISSING
HorizontalSplitCell	: "Split Cell Horizontally",	//MISSING
VerticalSplitCell	: "Split Cell Vertically",	//MISSING
TableDelete			: "លប់តារាង",
CellProperties		: "ការកំណត់សែល",
TableProperties		: "ការកំណត់តារាង",
ImageProperties		: "ការកំណត់រូបភាព",
FlashProperties		: "ការកំណត់ Flash",

AnchorProp			: "ការកំណត់យុថ្កា",
ButtonProp			: "ការកំណត់ ប៉ូតុន",
CheckboxProp		: "ការកំណត់ប្រអប់ជ្រើសរើស",
HiddenFieldProp		: "ការកំណត់ជួរលាក់",
RadioButtonProp		: "ការកំណត់ប៉ូតុនរង្វង់",
ImageButtonProp		: "ការកំណត់ប៉ូតុនរូបភាព",
TextFieldProp		: "ការកំណត់ជួរអត្ថបទ",
SelectionFieldProp	: "ការកំណត់ជួរជ្រើសរើស",
TextareaProp		: "ការកំណត់កន្លែងសរសេរអត្ថបទ",
FormProp			: "ការកំណត់បែបបទ",

FontFormats			: "Normal;Formatted;Address;Heading 1;Heading 2;Heading 3;Heading 4;Heading 5;Heading 6;Normal (DIV)",

// Alerts and Messages
ProcessingXHTML		: "កំពុងដំណើរការ XHTML ។ សូមរងចាំ...",
Done				: "ចប់រួចរាល់",
PasteWordConfirm	: "អត្ថបទដែលលោកអ្នកបំរុងចំលងដាក់ ហាក់បីដូចជាត្រូវចំលងមកពីកម្មវិធី​Word​។ តើលោកអ្នកចង់សំអាតមុនចំលងអត្ថបទដាក់ទេ?",
NotCompatiblePaste	: "ពាក្យបញ្ជានេះប្រើបានតែជាមួយ Internet Explorer កំរិត 5.5 រឺ លើសនេះ ។ តើលោកអ្នកចង់ចំលងដាក់ដោយមិនចាំបាច់សំអាតទេ?",
UnknownToolbarItem	: "វត្ថុលើរបាឧបរកណ៍ មិនស្គាល់ \"%1\"",
UnknownCommand		: "ឈ្មោះពាក្យបញ្ជា មិនស្គាល់ \"%1\"",
NotImplemented		: "ពាក្យបញ្ជា មិនបានអនុវត្ត",
UnknownToolbarSet	: "របាឧបរកណ៍ \"%1\" ពុំមាន ។",
NoActiveX			: "ការកំណត់សុវត្ថភាពរបស់កម្មវិធីរុករករបស់លោកអ្នក នេះ​អាចធ្វើអោយលោកអ្នកមិនអាចប្រើមុខងារខ្លះរបស់កម្មវិធីតាក់តែងអត្ថបទនេះ ។ លោកអ្នកត្រូវកំណត់អោយ \"ActiveX និង​កម្មវិធីជំនួយក្នុង (plug-ins)\" អោយដំណើរការ ។ លោកអ្នកអាចជួបប្រទះនឹង បញ្ហា ព្រមជាមួយនឹងការបាត់បង់មុខងារណាមួយរបស់កម្មវិធីតាក់តែងអត្ថបទនេះ ។",
BrowseServerBlocked : "The resources browser could not be opened. Make sure that all popup blockers are disabled.",	//MISSING
DialogBlocked		: "វីនដូវមិនអាចបើកបានទេ ។ សូមពិនិត្យចំពោះកម្មវិធីបិទ វីនដូវលោត (popup) ថាតើវាដំណើរការរឺទេ ។",
VisitLinkBlocked	: "It was not possible to open a new window. Make sure all popup blockers are disabled.",	//MISSING

// Dialogs
DlgBtnOK			: "យល់ព្រម",
DlgBtnCancel		: "មិនយល់ព្រម",
DlgBtnClose			: "បិទ",
DlgBtnBrowseServer	: "មើល",
DlgAdvancedTag		: "កំរិតខ្ពស់",
DlgOpOther			: "<ផ្សេងទៅត>",
DlgInfoTab			: "ពត៌មាន",
DlgAlertUrl			: "សូមសរសេរ URL",

// General Dialogs Labels
DlgGenNotSet		: "<មិនមែន>",
DlgGenId			: "Id",
DlgGenLangDir		: "ទិសដៅភាសា",
DlgGenLangDirLtr	: "ពីឆ្វេងទៅស្តាំ(LTR)",
DlgGenLangDirRtl	: "ពីស្តាំទៅឆ្វេង(RTL)",
DlgGenLangCode		: "លេខកូតភាសា",
DlgGenAccessKey		: "ឃី សំរាប់ចូល",
DlgGenName			: "ឈ្មោះ",
DlgGenTabIndex		: "លេខ Tab",
DlgGenLongDescr		: "អធិប្បាយ URL វែង",
DlgGenClass			: "Stylesheet Classes",
DlgGenTitle			: "ចំណងជើង ប្រឹក្សា",
DlgGenContType		: "ប្រភេទអត្ថបទ ប្រឹក្សា",
DlgGenLinkCharset	: "លេខកូតអក្សររបស់ឈ្នាប់",
DlgGenStyle			: "ម៉ូត",

// Image Dialog
DlgImgTitle			: "ការកំណត់រូបភាព",
DlgImgInfoTab		: "ពត៌មានអំពីរូបភាព",
DlgImgBtnUpload		: "បញ្ជូនទៅកាន់ម៉ាស៊ីនផ្តល់សេវា",
DlgImgURL			: "URL",
DlgImgUpload		: "ទាញយក",
DlgImgAlt			: "អត្ថបទជំនួស",
DlgImgWidth			: "ទទឹង",
DlgImgHeight		: "កំពស់",
DlgImgLockRatio		: "អត្រាឡុក",
DlgBtnResetSize		: "កំណត់ទំហំឡើងវិញ",
DlgImgBorder		: "ស៊ុម",
DlgImgHSpace		: "គំលាតទទឹង",
DlgImgVSpace		: "គំលាតបណ្តោយ",
DlgImgAlign			: "កំណត់ទីតាំង",
DlgImgAlignLeft		: "ខាងឆ្វង",
DlgImgAlignAbsBottom: "Abs Bottom",	//MISSING
DlgImgAlignAbsMiddle: "Abs Middle",	//MISSING
DlgImgAlignBaseline	: "បន្ទាត់ជាមូលដ្ឋាន",
DlgImgAlignBottom	: "ខាងក្រោម",
DlgImgAlignMiddle	: "កណ្តាល",
DlgImgAlignRight	: "ខាងស្តាំ",
DlgImgAlignTextTop	: "លើអត្ថបទ",
DlgImgAlignTop		: "ខាងលើ",
DlgImgPreview		: "មើលសាកល្បង",
DlgImgAlertUrl		: "សូមសរសេរងាស័យដ្ឋានរបស់រូបភាព",
DlgImgLinkTab		: "ឈ្នាប់",

// Flash Dialog
DlgFlashTitle		: "ការកំណត់ Flash",
DlgFlashChkPlay		: "លេងដោយស្វ័យប្រវត្ត",
DlgFlashChkLoop		: "ចំនួនដង",
DlgFlashChkMenu		: "បង្ហាញ មឺនុយរបស់ Flash",
DlgFlashScale		: "ទំហំ",
DlgFlashScaleAll	: "បង្ហាញទាំងអស់",
DlgFlashScaleNoBorder	: "មិនបង្ហាញស៊ុម",
DlgFlashScaleFit	: "ត្រូវល្មម",

// Link Dialog
DlgLnkWindowTitle	: "ឈ្នាប់",
DlgLnkInfoTab		: "ពត៌មានអំពីឈ្នាប់",
DlgLnkTargetTab		: "គោលដៅ",

DlgLnkType			: "ប្រភេទឈ្នាប់",
DlgLnkTypeURL		: "URL",
DlgLnkTypeAnchor	: "យុថ្កានៅក្នុងទំព័រនេះ",
DlgLnkTypeEMail		: "អ៊ីមែល",
DlgLnkProto			: "ប្រូតូកូល",
DlgLnkProtoOther	: "<ផ្សេងទៀត>",
DlgLnkURL			: "URL",
DlgLnkAnchorSel		: "ជ្រើសរើសយុថ្កា",
DlgLnkAnchorByName	: "តាមឈ្មោះរបស់យុថ្កា",
DlgLnkAnchorById	: "តាម Id",
DlgLnkNoAnchors		: "(No anchors available in the document)",	//MISSING
DlgLnkEMail			: "អ៊ីមែល",
DlgLnkEMailSubject	: "ចំណងជើងអត្ថបទ",
DlgLnkEMailBody		: "អត្ថបទ",
DlgLnkUpload		: "ទាញយក",
DlgLnkBtnUpload		: "ទាញយក",

DlgLnkTarget		: "គោលដៅ",
DlgLnkTargetFrame	: "<ហ្វ្រេម>",
DlgLnkTargetPopup	: "<វីនដូវ លោត>",
DlgLnkTargetBlank	: "វីនដូវថ្មី (_blank)",
DlgLnkTargetParent	: "វីនដូវមេ (_parent)",
DlgLnkTargetSelf	: "វីនដូវដដែល (_self)",
DlgLnkTargetTop		: "វីនដូវនៅលើគេ(_top)",
DlgLnkTargetFrameName	: "ឈ្មោះហ្រ្វេមដែលជាគោលដៅ",
DlgLnkPopWinName	: "ឈ្មោះវីនដូវលោត",
DlgLnkPopWinFeat	: "លក្ខណះរបស់វីនដូលលោត",
DlgLnkPopResize		: "ទំហំអាចផ្លាស់ប្តូរ",
DlgLnkPopLocation	: "របា ទីតាំង",
DlgLnkPopMenu		: "របា មឺនុយ",
DlgLnkPopScroll		: "របា ទាញ",
DlgLnkPopStatus		: "របា ពត៌មាន",
DlgLnkPopToolbar	: "របា ឩបករណ៍",
DlgLnkPopFullScrn	: "អេក្រុងពេញ(IE)",
DlgLnkPopDependent	: "អាស្រ័យលើ (Netscape)",
DlgLnkPopWidth		: "ទទឹង",
DlgLnkPopHeight		: "កំពស់",
DlgLnkPopLeft		: "ទីតាំងខាងឆ្វេង",
DlgLnkPopTop		: "ទីតាំងខាងលើ",

DlnLnkMsgNoUrl		: "សូមសរសេរ អាស័យដ្ឋាន URL",
DlnLnkMsgNoEMail	: "សូមសរសេរ អាស័យដ្ឋាន អ៊ីមែល",
DlnLnkMsgNoAnchor	: "សូមជ្រើសរើស យុថ្កា",
DlnLnkMsgInvPopName	: "The popup name must begin with an alphabetic character and must not contain spaces",	//MISSING

// Color Dialog
DlgColorTitle		: "ជ្រើសរើស ពណ៌",
DlgColorBtnClear	: "លប់",
DlgColorHighlight	: "ផាត់ពណ៌",
DlgColorSelected	: "បានជ្រើសរើស",

// Smiley Dialog
DlgSmileyTitle		: "បញ្ជូលរូបភាព",

// Special Character Dialog
DlgSpecialCharTitle	: "តូអក្សរពិសេស",

// Table Dialog
DlgTableTitle		: "ការកំណត់ តារាង",
DlgTableRows		: "ជួរផ្តេក",
DlgTableColumns		: "ជួរឈរ",
DlgTableBorder		: "ទំហំស៊ុម",
DlgTableAlign		: "ការកំណត់ទីតាំង",
DlgTableAlignNotSet	: "<មិនកំណត់>",
DlgTableAlignLeft	: "ខាងឆ្វេង",
DlgTableAlignCenter	: "កណ្តាល",
DlgTableAlignRight	: "ខាងស្តាំ",
DlgTableWidth		: "ទទឹង",
DlgTableWidthPx		: "ភីកសែល",
DlgTableWidthPc		: "ភាគរយ",
DlgTableHeight		: "កំពស់",
DlgTableCellSpace	: "គំលាតសែល",
DlgTableCellPad		: "គែមសែល",
DlgTableCaption		: "ចំណងជើង",
DlgTableSummary		: "សេចក្តីសង្ខេប",
DlgTableHeaders		: "Headers",	//MISSING
DlgTableHeadersNone		: "None",	//MISSING
DlgTableHeadersColumn	: "First column",	//MISSING
DlgTableHeadersRow		: "First Row",	//MISSING
DlgTableHeadersBoth		: "Both",	//MISSING

// Table Cell Dialog
DlgCellTitle		: "ការកំណត់ សែល",
DlgCellWidth		: "ទទឹង",
DlgCellWidthPx		: "ភីកសែល",
DlgCellWidthPc		: "ភាគរយ",
DlgCellHeight		: "កំពស់",
DlgCellWordWrap		: "បង្ហាញអត្ថបទទាំងអស់",
DlgCellWordWrapNotSet	: "<មិនកំណត់>",
DlgCellWordWrapYes	: "បាទ(ចា)",
DlgCellWordWrapNo	: "ទេ",
DlgCellHorAlign		: "តំរឹមផ្តេក",
DlgCellHorAlignNotSet	: "<មិនកំណត់>",
DlgCellHorAlignLeft	: "ខាងឆ្វេង",
DlgCellHorAlignCenter	: "កណ្តាល",
DlgCellHorAlignRight: "Right",	//MISSING
DlgCellVerAlign		: "តំរឹមឈរ",
DlgCellVerAlignNotSet	: "<មិនកណត់>",
DlgCellVerAlignTop	: "ខាងលើ",
DlgCellVerAlignMiddle	: "កណ្តាល",
DlgCellVerAlignBottom	: "ខាងក្រោម",
DlgCellVerAlignBaseline	: "បន្ទាត់ជាមូលដ្ឋាន",
DlgCellType		: "Cell Type",	//MISSING
DlgCellTypeData		: "Data",	//MISSING
DlgCellTypeHeader	: "Header",	//MISSING
DlgCellRowSpan		: "បញ្ជូលជួរផ្តេក",
DlgCellCollSpan		: "បញ្ជូលជួរឈរ",
DlgCellBackColor	: "ពណ៌ផ្នែកខាងក្រោម",
DlgCellBorderColor	: "ពណ៌ស៊ុម",
DlgCellBtnSelect	: "ជ្រើសរើស...",

// Find and Replace Dialog
DlgFindAndReplaceTitle	: "Find and Replace",	//MISSING

// Find Dialog
DlgFindTitle		: "ស្វែងរក",
DlgFindFindBtn		: "ស្វែងរក",
DlgFindNotFoundMsg	: "ពាក្យនេះ រកមិនឃើញទេ ។",

// Replace Dialog
DlgReplaceTitle			: "ជំនួស",
DlgReplaceFindLbl		: "ស្វែងរកអ្វី:",
DlgReplaceReplaceLbl	: "ជំនួសជាមួយ:",
DlgReplaceCaseChk		: "ករណ៉ត្រូវរក",
DlgReplaceReplaceBtn	: "ជំនួស",
DlgReplaceReplAllBtn	: "ជំនួសទាំងអស់",
DlgReplaceWordChk		: "ត្រូវពាក្យទាំងអស់",

// Paste Operations / Dialog
PasteErrorCut	: "ការកំណត់សុវត្ថភាពរបស់កម្មវិធីរុករករបស់លោកអ្នក នេះ​មិនអាចធ្វើកម្មវិធីតាក់តែងអត្ថបទ កាត់អត្ថបទយកដោយស្វ័យប្រវត្តបានឡើយ ។ សូមប្រើប្រាស់បន្សំ ឃីដូចនេះ  (Ctrl+X) ។",
PasteErrorCopy	: "ការកំណត់សុវត្ថភាពរបស់កម្មវិធីរុករករបស់លោកអ្នក នេះ​មិនអាចធ្វើកម្មវិធីតាក់តែងអត្ថបទ ចំលងអត្ថបទយកដោយស្វ័យប្រវត្តបានឡើយ ។ សូមប្រើប្រាស់បន្សំ ឃីដូចនេះ (Ctrl+C)។",

PasteAsText		: "ចំលងដាក់អត្ថបទធម្មតា",
PasteFromWord	: "ចំលងពាក្យពីកម្មវិធី Word",

DlgPasteMsg2	: "សូមចំលងអត្ថបទទៅដាក់ក្នុងប្រអប់ដូចខាងក្រោមដោយប្រើប្រាស់ ឃី ​(<STRONG>Ctrl+V</STRONG>) ហើយចុច <STRONG>OK</STRONG> ។",
DlgPasteSec		: "Because of your browser security settings, the editor is not able to access your clipboard data directly. You are required to paste it again in this window.",	//MISSING
DlgPasteIgnoreFont		: "មិនគិតអំពីប្រភេទពុម្ភអក្សរ",
DlgPasteRemoveStyles	: "លប់ម៉ូត",

// Color Picker
ColorAutomatic	: "ស្វ័យប្រវត្ត",
ColorMoreColors	: "ពណ៌ផ្សេងទៀត..",

// Document Properties
DocProps		: "ការកំណត់ ឯកសារ",

// Anchor Dialog
DlgAnchorTitle		: "ការកំណត់ចំណងជើងយុទ្ធថ្កា",
DlgAnchorName		: "ឈ្មោះយុទ្ធថ្កា",
DlgAnchorErrorName	: "សូមសរសេរ ឈ្មោះយុទ្ធថ្កា",

// Speller Pages Dialog
DlgSpellNotInDic		: "គ្មានក្នុងវចនានុក្រម",
DlgSpellChangeTo		: "ផ្លាស់ប្តូរទៅ",
DlgSpellBtnIgnore		: "មិនផ្លាស់ប្តូរ",
DlgSpellBtnIgnoreAll	: "មិនផ្លាស់ប្តូរ ទាំងអស់",
DlgSpellBtnReplace		: "ជំនួស",
DlgSpellBtnReplaceAll	: "ជំនួសទាំងអស់",
DlgSpellBtnUndo			: "សារឡើងវិញ",
DlgSpellNoSuggestions	: "- គ្មានសំណើរ -",
DlgSpellProgress		: "កំពុងពិនិត្យអក្ខរាវិរុទ្ធ...",
DlgSpellNoMispell		: "ការពិនិត្យអក្ខរាវិរុទ្ធបានចប់: គ្មានកំហុស",
DlgSpellNoChanges		: "ការពិនិត្យអក្ខរាវិរុទ្ធបានចប់: ពុំមានផ្លាស់ប្តូរ",
DlgSpellOneChange		: "ការពិនិត្យអក្ខរាវិរុទ្ធបានចប់: ពាក្យមួយត្រូចបានផ្លាស់ប្តូរ",
DlgSpellManyChanges		: "ការពិនិត្យអក្ខរាវិរុទ្ធបានចប់: %1 ពាក្យបានផ្លាស់ប្តូរ",

IeSpellDownload			: "ពុំមានកម្មវិធីពិនិត្យអក្ខរាវិរុទ្ធ ។ តើចង់ទាញយកពីណា?",

// Button Dialog
DlgButtonText		: "អត្ថបទ(តំលៃ)",
DlgButtonType		: "ប្រភេទ",
DlgButtonTypeBtn	: "Button",	//MISSING
DlgButtonTypeSbm	: "Submit",	//MISSING
DlgButtonTypeRst	: "Reset",	//MISSING

// Checkbox and Radio Button Dialogs
DlgCheckboxName		: "ឈ្មោះ",
DlgCheckboxValue	: "តំលៃ",
DlgCheckboxSelected	: "បានជ្រើសរើស",

// Form Dialog
DlgFormName		: "ឈ្មោះ",
DlgFormAction	: "សកម្មភាព",
DlgFormMethod	: "វិធី",

// Select Field Dialog
DlgSelectName		: "ឈ្មោះ",
DlgSelectValue		: "តំលៃ",
DlgSelectSize		: "ទំហំ",
DlgSelectLines		: "បន្ទាត់",
DlgSelectChkMulti	: "អនុញ្ញាតអោយជ្រើសរើសច្រើន",
DlgSelectOpAvail	: "ការកំណត់ជ្រើសរើស ដែលអាចកំណត់បាន",
DlgSelectOpText		: "ពាក្យ",
DlgSelectOpValue	: "តំលៃ",
DlgSelectBtnAdd		: "បន្ថែម",
DlgSelectBtnModify	: "ផ្លាស់ប្តូរ",
DlgSelectBtnUp		: "លើ",
DlgSelectBtnDown	: "ក្រោម",
DlgSelectBtnSetValue : "Set as selected value",	//MISSING
DlgSelectBtnDelete	: "លប់",

// Textarea Dialog
DlgTextareaName	: "ឈ្មោះ",
DlgTextareaCols	: "ជូរឈរ",
DlgTextareaRows	: "ជូរផ្តេក",

// Text Field Dialog
DlgTextName			: "ឈ្មោះ",
DlgTextValue		: "តំលៃ",
DlgTextCharWidth	: "ទទឹង អក្សរ",
DlgTextMaxChars		: "អក្សរអតិបរិមា",
DlgTextType			: "ប្រភេទ",
DlgTextTypeText		: "ពាក្យ",
DlgTextTypePass		: "ពាក្យសំងាត់",

// Hidden Field Dialog
DlgHiddenName	: "ឈ្មោះ",
DlgHiddenValue	: "តំលៃ",

// Bulleted List Dialog
BulletedListProp	: "កំណត់បញ្ជីរង្វង់",
NumberedListProp	: "កំណត់បញ្េជីលេខ",
DlgLstStart			: "Start",	//MISSING
DlgLstType			: "ប្រភេទ",
DlgLstTypeCircle	: "រង្វង់",
DlgLstTypeDisc		: "Disc",
DlgLstTypeSquare	: "ការេ",
DlgLstTypeNumbers	: "លេខ(1, 2, 3)",
DlgLstTypeLCase		: "អក្សរតូច(a, b, c)",
DlgLstTypeUCase		: "អក្សរធំ(A, B, C)",
DlgLstTypeSRoman	: "អក្សរឡាតាំងតូច(i, ii, iii)",
DlgLstTypeLRoman	: "អក្សរឡាតាំងធំ(I, II, III)",

// Document Properties Dialog
DlgDocGeneralTab	: "ទូទៅ",
DlgDocBackTab		: "ផ្នែកខាងក្រោយ",
DlgDocColorsTab		: "ទំព័រ​និង ស៊ុម",
DlgDocMetaTab		: "ទិន្នន័យមេ",

DlgDocPageTitle		: "ចំណងជើងទំព័រ",
DlgDocLangDir		: "ទិសដៅសរសេរភាសា",
DlgDocLangDirLTR	: "ពីឆ្វេងទៅស្ដាំ(LTR)",
DlgDocLangDirRTL	: "ពីស្ដាំទៅឆ្វេង(RTL)",
DlgDocLangCode		: "លេខកូតភាសា",
DlgDocCharSet		: "កំណត់លេខកូតភាសា",
DlgDocCharSetCE		: "Central European",	//MISSING
DlgDocCharSetCT		: "Chinese Traditional (Big5)",	//MISSING
DlgDocCharSetCR		: "Cyrillic",	//MISSING
DlgDocCharSetGR		: "Greek",	//MISSING
DlgDocCharSetJP		: "Japanese",	//MISSING
DlgDocCharSetKR		: "Korean",	//MISSING
DlgDocCharSetTR		: "Turkish",	//MISSING
DlgDocCharSetUN		: "Unicode (UTF-8)",	//MISSING
DlgDocCharSetWE		: "Western European",	//MISSING
DlgDocCharSetOther	: "កំណត់លេខកូតភាសាផ្សេងទៀត",

DlgDocDocType		: "ប្រភេទក្បាលទំព័រ",
DlgDocDocTypeOther	: "ប្រភេទក្បាលទំព័រផ្សេងទៀត",
DlgDocIncXHTML		: "បញ្ជូល XHTML",
DlgDocBgColor		: "ពណ៌ខាងក្រោម",
DlgDocBgImage		: "URL របស់រូបភាពខាងក្រោម",
DlgDocBgNoScroll	: "ទំព័រក្រោមមិនប្តូរ",
DlgDocCText			: "អត្តបទ",
DlgDocCLink			: "ឈ្នាប់",
DlgDocCVisited		: "ឈ្នាប់មើលហើយ",
DlgDocCActive		: "ឈ្នាប់កំពុងមើល",
DlgDocMargins		: "ស៊ុមទំព័រ",
DlgDocMaTop			: "លើ",
DlgDocMaLeft		: "ឆ្វេង",
DlgDocMaRight		: "ស្ដាំ",
DlgDocMaBottom		: "ក្រោម",
DlgDocMeIndex		: "ពាក្យនៅក្នុងឯកសារ (ផ្តាច់ពីគ្នាដោយក្បៀស)",
DlgDocMeDescr		: "សេចក្តីអត្ថាធិប្បាយអំពីឯកសារ",
DlgDocMeAuthor		: "អ្នកនិពន្ធ",
DlgDocMeCopy		: "រក្សាសិទ្ធិ៏",
DlgDocPreview		: "មើលសាកល្បង",

// Templates Dialog
Templates			: "ឯកសារគំរូ",
DlgTemplatesTitle	: "ឯកសារគំរូ របស់អត្ថន័យ",
DlgTemplatesSelMsg	: "សូមជ្រើសរើសឯកសារគំរូ ដើម្បីបើកនៅក្នុងកម្មវិធីតាក់តែងអត្ថបទ<br>(អត្ថបទនឹងបាត់បង់):",
DlgTemplatesLoading	: "កំពុងអានបញ្ជីឯកសារគំរូ ។ សូមរងចាំ...",
DlgTemplatesNoTpl	: "(ពុំមានឯកសារគំរូត្រូវបានកំណត់)",
DlgTemplatesReplace	: "Replace actual contents",	//MISSING

// About Dialog
DlgAboutAboutTab	: "អំពី",
DlgAboutBrowserInfoTab	: "ព៌តមានកម្មវិធីរុករក",
DlgAboutLicenseTab	: "License",	//MISSING
DlgAboutVersion		: "ជំនាន់",
DlgAboutInfo		: "សំរាប់ព៌តមានផ្សេងទៀត សូមទាក់ទង",

// Div Dialog
DlgDivGeneralTab	: "General",	//MISSING
DlgDivAdvancedTab	: "Advanced",	//MISSING
DlgDivStyle		: "Style",	//MISSING
DlgDivInlineStyle	: "Inline Style",	//MISSING

ScaytTitle			: "SCAYT",	//MISSING
ScaytTitleOptions	: "Options",	//MISSING
ScaytTitleLangs		: "Languages",	//MISSING
ScaytTitleAbout		: "About"	//MISSING
};
